pub struct DecreaseLiquidityV2Bumps {
pub protocol_position: u8,
}Fields
protocol_position: u8Trait Implementations
sourceimpl<'info> Accounts<'info, DecreaseLiquidityV2Bumps> for DecreaseLiquidityV2<'info>where
'info: 'info,
impl<'info> Accounts<'info, DecreaseLiquidityV2Bumps> for DecreaseLiquidityV2<'info>where
'info: 'info,
sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut DecreaseLiquidityV2Bumps,
__reallocs: &mut BTreeSet<Pubkey>
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut DecreaseLiquidityV2Bumps, __reallocs: &mut BTreeSet<Pubkey> ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moresourceimpl Debug for DecreaseLiquidityV2Bumps
impl Debug for DecreaseLiquidityV2Bumps